@@ -82,7 +82,7 @@ class BaseLog:
             "log_time": self.date_log_time(),  # 时间
             "level": log_level,  # 日志界别
             "thread": threading.currentThread().ident,  # 线程编号
-            "code_message": message,  # 消息
+            "code_message": message[:3000],  # 消息
             "pathName": path_name,  # 打印日志位置
             "lineNo": lineno,  # 打印日志行号
             "funcName": func_name,  # 打印日志方法名
@@ -215,17 +215,17 @@ class BaseLog:
             "address": request_url,
             "fcode": f_code if dialog_type == 'in' else self.t_code,
             "tcode": self.t_code if dialog_type == 'in' else f_code,
-            "method_code": method_code,
-            "http_method": http_method,
+            "method_code": str(method_code or ""),
+            "http_method": str(http_method or ""),
             "request_time": request_time.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3],
             "request_headers": request_headers,
             "request_payload": request_content,
             "response_headers": response_headers,
             "response_payload": response_content,
             "response_time": response_time.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3],
-            "response_code": response_code,
+            "response_code": str(response_code or ""),
             "response_remark": remark,
-            "http_status_code": http_status_code,
+            "http_status_code": str(http_status_code or ""),
             "order_id": order_id,
             "account_type": account_type,
             "account_num": phone_num,
